@@ -1,13 +1,10 @@
-import requests
-import json
-
-from tasq_cli.settings import SERVER, TOKEN
 from tasq_cli import settings
 from tasq_cli.server import make_request
 
 logger = None
 
-def run_job(project_id, tag):
+
+def run_job(project_id, tag, exclude_tag=None):
     global logger
     logger = settings.get_logger()
     url = f'/jobs'
@@ -22,7 +19,7 @@ def run_job(project_id, tag):
                 'includeModel': False,
                 'resourcesFilter': {
                     'tags': [tag],
-                    'excludeTags': [],
+                    'excludeTags': [exclude_tag],
                 },
                 'maxResources': None,
                 'forQualification': False,
@@ -50,13 +47,13 @@ def list_jobs(project_id):
 def export_job(job_id, raw, worker_data):
     global logger
     logger = settings.get_logger()
-    type = 'target'
+    type_ = 'target'
     params = '&all_judgements=false'
     if raw:
-        type='raw'
+        type_ = 'raw'
     elif worker_data:
         params = '&all_judgements=true&include_worker_data=true'
-    url = f'/jobs/{job_id}/download/?export_type={type}{params}'
+    url = f'/jobs/{job_id}/download/?export_type={type_}{params}'
     r = make_request(url)
     data = r.json()
     return data
