@@ -1,12 +1,11 @@
-import requests
 import json
 
-from tasq_cli.settings import SERVER, TOKEN
 from tasq_cli import settings
 from tasq_cli.server import make_request
 
 logger = None
 
+
 def list_projects():
     global logger
     logger = settings.get_logger()
@@ -16,4 +15,4 @@ def list_projects():
     for j in data:
         del(j['relationships'])
     print(json.dumps(data))
-    return
\ No newline at end of file
+    return
